#!/usr/bin/env bash

########################################################################################################################
# 
# This script will copy the data from /gpfs/home (nvmes) to /gpfs/scratch, which are
# disks.
#
# VARIABLE INDEX: 
#
# internal autosubmit:
#
# CURRENT_ROOTDIR: remote scratch dir (default Autosubmit)
# MEMBER: this job's member
# EXPID: experiment id of Autosubmit
# SDATE: start date of this workflow
#
# in expdef_cxxx.conf (if you use TODO INSERT HASH) data you should not change this:
#
# ECEARTH_OUTPUT: path to the experiment which we will link its data (/gpfs/scratch/bsc32/bsc032371/cxxx)
# ECEARTH_OUTPUT_SDATE: start date of the original data (i.e. YYYYMMDD)
# ECEARTH_OUTPUT_MEMBER: original data member (fc0, fc1). It shoud match MEMBER
# ECEARTH_OUTPUT_CHUNK: original data chunk
# ECEARTH_OUTPUT_EXPID: original data expid
#
# Manuel G. Marciani
# BSC-CNS - Earth Sciences Department
# 2024
#
########################################################################################################################

CURRENT_ROOTDIR=%CURRENT_ROOTDIR%
CURRENT_MEMBER=%MEMBER%
CURRENT_EXPID=%EXPID%
CURRENT_SDATE=%SDATE%
DATA_MEMBER=%ECEARTH_OUTPUT_MEMBER%
DATA_OUTPUT=%ECEARTH_OUTPUT%
DATA_CHUNK=%ECEARTH_OUTPUT_CHUNK%
DATA_SDATE=%ECEARTH_OUTPUT_SDATE%
DATA_EXPID=%ECEARTH_OUTPUT_EXPID%

# we copy everything but hidden files and folders
rsync --recursive --links --times --chmod=ugo=rw --devices --specials --verbose --exclude=".*" ${DATA_OUTPUT}/${DATA_SDATE} ${CURRENT_ROOTDIR}/

pushd $CURRENT_ROOTDIR/$DATA_SDATE
# looks for all files with the original experiment's expid on their name
# looking from data_output!
files_to_update=$(find . -name *$DATA_EXPID*)

for file in $files_to_update; do
    mv $file $(echo $file | sed -e 's/'$DATA_EXPID'/'$CURRENT_EXPID'/')
done

popd
