#!/usr/bin/env bash

########################################################################################################################
# 
# This script checks the configuration of the workflow. 
#
# VARIABLE INDEX: 
#
# internal autosubmit:
#
# CURRENT_ROOTDIR: remote scratch dir (default Autosubmit)
# MEMBER: this job's member
# EXPID: experiment id of Autosubmit
# SDATE: start date of this workflow
#
# in expdef_cxxx.conf (if you use TODO INSERT HASH) data you should not change this:
#
# ECEARTH_OUTPUT: path to the experiment which we will link its data (/gpfs/scratch/bsc32/bsc032371/cxxx)
# ECEARTH_OUTPUT_SDATE: original data startdate. It should match SDATE
# ECEARTH_OUTPUT_MEMBER: original data member (fc0, fc1). It shoud match MEMBER
# ECEARTH_OUTPUT_MEMBERS: list of members of the original data. It should match MEMBERS
# ECEARTH_OUTPUT_MODEL_RES: resolution of the original data
# ECEARTH_OUTPUT_VERSION: model version that produced the original data
# ECEARTH_OUTPUT_BSC_OUTCLASS: cmorization configuration from bsc of the original data
# ECEARTH_OUTPUT_CMOR_ACTIVITY_ID: identification of the cmor execise 
# ECEARTH_OUTPUT_CMOR_EXP: experiment of the cmor (pre-industrial control, piControl, etc)
# ECEARTH_OUTPUT_CMOR_MODEL_ID: id of the model to produce original data
# ECEARTH_OUTPUT_LPJG: boolean to indicate if lpjg is enabled
# ECEARTH_OUTPUT_CHUNK: original data chunk
# ECEARTH_OUTPUT_CHUNK_START_DATE: original data Chunk Start date
# ECEARTH_OUTPUT_CHUNK_END_DATE: original data chunk's end date
# ECEARTH_OUTPUT_CHUNK_LAST: lst chunk to be cmorized
# ECEARTH_OUTPUT_CHUNKSIZE: lenght in months of the chunk (12 months, 6, etc)
# ECEARTH_OUTPUT_NFRP: IFS configuration
# ECEARTH_OUTPUT_NEMO_RESOLUTION: nemo grid indentifier of the original data
# ECEARTH_OUTPUT_IFS_RESOLUTION: ifs grid identifier of the original data
# ECEARTH_OUTPUT_PROJ_TYPE: original data project type
# ECEARTH_OUTPUT_PRODUCTION_EXP: boolean indicating if the original data is production experiment
# ECEARTH_OUTPUT_CMORIZATION: boolean that enables/disables cmorization
# ECEARTH_OUTPUT_CMOR_EXP_CUSTOM: custom flag for cmorization
# ECEARTH_OUTPUT_CMOR_ADD_STARTDATE: custom startdata for cmorization
# ECEARTH_OUTPUT_TEMPLATE_NAME: original dta template name
#
# Manuel G. Marciani
# BSC-CNS - Earth Sciences Department
# 2024
#
########################################################################################################################

CURRENT_ROOTDIR=%CURRENT_ROOTDIR%
CURRENT_MEMBER=%MEMBER%
CURRENT_EXPID=%EXPID%
CURRENT_SDATE=%SDATE%
DATA_MEMBER=%ECEARTH_OUTPUT_MEMBER%
DATA_OUTPUT=%ECEARTH_OUTPUT%
DATA_CHUNK=%ECEARTH_OUTPUT_CHUNK%
DATA_SDATE=%ECEARTH_OUTPUT_SDATE%
DATA_EXPID=%ECEARTH_OUTPUT_EXPID%

# sanitize the configuration
if [ -z "${DATA_MEMBER}" ]; then
    >&2 echo "Data's member in expdef_cxxx.cond 'ECEARTH_OUTPUT_MEMBER' is unset."
	exit
fi

if [ -z "${DATA_OUTPUT}" ]; then
    >&2 echo "Data's member in expdef_cxxx.cond 'ECEARTH_OUTPUT_MEMBER' is unset."
	exit
fi

if [ -z "${DATA_CHUNK}" ]; then
    >&2 echo "Data's chunk in expdef_cxxx.cond 'ECEARTH_OUTPUT_CHUNK' is unset."
	exit
fi

if [ -z "${DATA_SDATE}" ]; then
    >&2 echo "Data's start date in expdef_cxxx.cond 'ECEARTH_OUTPUT_SDATE' is unset."
	exit
fi

if [ -z "${DATA_EXPID}" ]; then
    >&2 echo "Data's expid in expdef_cxxx.cond 'ECEARTH_OUTPUT_EXPID' is unset."
	exit
fi

# check if the workflow's start date and the data's match 
if [[ "$CURRENT_SDATE" != "$DATA_SDATE" ]]; then
    # print to stderr
    >&2 echo "Data's start date in expdef_cxxx.conf 'ECEARTH_OUTPUT_SDATE' and this workflow's start date in expdef_cxxx.conf 'DATELIST' should be the same."
    exit $ERRCODE
fi

pushd ${DATA_OUTPUT}/${DATA_SDATE}/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/ifs/${DATA_CHUNK}

# check if the workflow's start date and the data's match
if [[ "$CURRENT_MEMBER" != "$DATA_MEMBER" ]]; then
    # print to stderr
    >&2 echo "Data's member in expdef_cxxx.conf 'ECEARTH_OUTPUT_MEMBER' and this workflow's member in expdef_cxxx.conf 'MEMBERS' should be the same."
    exit $ERRCODE
fi

# check if configured expid in in the file name
for ifs_output_file in $(ls -1); do
    if [[ $DATA_EXPID == *"$ifs_output_file"*  ]]; then
        nop
    else
        >&2 echo "File ${ifs_output_file} expid and configuration 'ECEARTH_OUTPUT_EXPID' in expdef_cxxx.conf do not match."
        exit $ERRCODE
    fi
done

popd

# there is no need for adapting ofx-data!
pushd ${DATA_OUTPUT}/${DATA_SDATE}/${DATA_SDATE}/${DATA_MEMBER}/runtime/output/nemo/${DATA_CHUNK}

for nemo_output_file in $(ls -1); do
    # check if the expid is present in the file name
    if [[ $DATA_EXPID == *"$nemo_output_file"*  ]]; then
        mv $nemo_output_file $(echo $nemo_output_file | sed -e 's/${DATA_EXPID}/${EXPID}/') 
    else
        >&2 echo "File ${nemo_output_file} expid and configuration 'ECEARTH_OUTPUT_EXPID' in expdef_cxxx.conf do not match."
        exit $ERRCODE
    fi
done
